==> DAAG_0.94.tar.gz: DAAG/data/hills2000.R <==
`hills2000` <-
structure(list(h = c(0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 
0, 0, 0, 0, 8, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 2, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 1, 2, 1, 2, 0
), m = c(46, 47, 18, 27, 32, 37, 27, 16, 23, 59, 33, 2, 23, 13, 
25, 40, 29, 37, 18, 44, 37, 11, 22, 13, 11, 44, 34, 38, 19, 26, 
44, 46, 30, 27, 17, 17, 47, 58, 43, 27, 34, 12, 33, 39, 3, 13, 
25, 19, 42, 39, 36, 8, 33, 11, 22, 29), s = c(56, 36, 52, 51, 
46, 24, 32, 44, 44, 0, 10, 16, 14, 40, 52, 44, 45, 6, 25, 23, 
26, 35, 54, 13, 53, 32, 22, 18, 40, 52, 41, 26, 32, 54, 5, 39, 
39, 34, 0, 50, 2, 31, 49, 57, 11, 56, 34, 56, 16, 53, 33, 0, 
57, 4, 40, 58), h0 = c(0, 1, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 
1, 0, 0, 0, NA, 13, 0, 0, 1, 0, 2, 1, 0, 0, 0, 1, 0, 0, 1, 0, 
0, 0, 0, 1, 2, 0, 0, 2, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 1, 3, 1, 
2, 0), m0 = c(55, 0, 22, 36, 37, 44, 32, 29, 27, 23, 38, 11, 
27, 31, 32, 50, 34, NA, 32, 52, 44, 27, 29, 42, 26, 52, 41, 46, 
46, 31, 56, 0, 46, 36, 21, 28, 3, 21, 56, 36, 57, 14, 43, 49, 
17, 17, 43, 26, 48, 57, 47, 23, 5, 29, 47, 34), s0 = c(9, 12, 
36, 33, 33, 3, 37, 16, 51, 56, 16, 57, 9, 35, 24, 14, 45, NA, 
52, 27, 55, 4, 5, 17, 59, 13, 42, 25, 58, 56, 10, 54, 6, 35, 
38, 23, 7, 21, 36, 6, 44, 48, 27, 4, 38, 56, 25, 13, 35, 48, 
9, 41, 18, 51, 6, 52), dist = c(6, 7, 1.5, 5, 6, 5, 4, 10.5, 
3.5, 14, 5, 9, 4, 8, 3.5, 7, 5, 5.5, 46, 6, 6.5, 8, 2.5, 13, 
10, 6, 6, 6, 9, 4, 4.5, 6, 5.5, 3.5, 2, 2, 6, 14, 7, 3, 15, 2.5, 
5.5, 6, 9, 2.25, 10, 2, 6, 16, 5, 8, 18, 10, 16, 4.5), climb = c(2500, 
1800, 1400, 700, 900, 1200, 1300, 3500, 800, 5000, 1250, 3192, 
800, 2866, 1250, 600, 800, 800, 7500, 1400, 650, 2500, 1400, 
5500, 2000, 1500, 900, 2000, 2950, 600, 2400, 1400, 728, 1500, 
900, 900, 2500, 4900, 500, 1223, 5500, 800, 741, 1220, 2200, 
500, 4400, 1500, 1400, 2250, 1700, 2710, 4900, 2300, 6200, 1500
), time = c(0.782222222222222, 0.793333333333333, 0.314444444444444, 
0.464166666666667, 0.546111111111111, 0.623333333333333, 0.458888888888889, 
1.27888888888889, 0.395555555555556, 1.98333333333333, 0.552777777777778, 
1.03777777777778, 0.387222222222222, 1.22777777777778, 0.431111111111111, 
0.678888888888889, 0.495833333333333, 0.618333333333333, 8.30694444444445, 
0.739722222222222, 0.623888888888889, 1.19305555555556, 0.381666666666667, 
2.22027777777778, 1.19805555555556, 0.742222222222222, 0.572777777777778, 
0.638333333333333, 1.32777777777778, 0.447777777777778, 0.744722222222222, 
0.773888888888889, 0.508888888888889, 0.465, 0.284722222222222, 
0.294166666666667, 0.794166666666667, 1.97611111111111, 0.716666666666667, 
0.463888888888889, 2.56722222222222, 0.208611111111111, 0.563611111111111, 
0.665833333333333, 1.05305555555556, 0.232222222222222, 1.42611111111111, 
0.332222222222222, 0.704444444444444, 1.66472222222222, 0.609166666666667, 
1.13333333333333, 2.56583333333333, 1.18444444444444, 2.37777777777778, 
0.499444444444444), timef = c(0.919166666666667, 1.00333333333333, 
0.376666666666667, 0.609166666666667, 0.625833333333333, 0.734166666666667, 
0.543611111111111, 1.48777777777778, 0.464166666666667, 2.39888888888889, 
0.637777777777778, 1.19916666666667, 0.4525, 1.52638888888889, 
0.54, 0.837222222222222, 0.579166666666667, NA, 13.5477777777778, 
0.874166666666667, 0.748611111111111, 1.45111111111111, 0.484722222222222, 
2.70472222222222, 1.44972222222222, 0.870277777777778, 0.695, 
0.773611111111111, 1.78277777777778, 0.532222222222222, 0.936111111111111, 
1.015, 0.768333333333333, 0.609722222222222, 0.360555555555556, 
0.473055555555556, 1.05194444444444, 2.35583333333333, 0.943333333333333, 
0.601666666666667, 2.96222222222222, 0.246666666666667, 0.724166666666667, 
0.817777777777778, 1.29388888888889, 0.298888888888889, 1.72361111111111, 
0.436944444444444, 0.809722222222222, 1.96333333333333, 0.785833333333333, 
1.39472222222222, 3.08833333333333, 1.4975, 2.785, 0.581111111111111
)), .Names = c("h", "m", "s", "h0", "m0", "s0", "dist", "climb", 
"time", "timef"), class = "data.frame", row.names = c("Tiso Carnethy", 
"Criffel", "Chapelgill", "Norman's Law", "Craig Dunain", "Knockfarrel", 
"Screel", "O.P.S. Clachnaben", "Whangie Whizz", "Stuc A'Chroin", 
"29th Dumyat", "Ben Lomond", "Kinnoull", "Goatfell", "Scottish Nuclear Kaim", 
"Ardoch Rig", "Scolty", "Cornalees", "12 Trig Trog", "Kilpatricks", 
"Traprain", "Yetholm", "Ben Sheann", "Glen Rosa", "Scottish Borders", 
"Cort-ma", "White Tops", "Dollar", "Ben Tee", "Black Hill", "Glamaig", 
"Urie Loch", "Whiteash", "Meall Ant-Suidhe", "Lochaber AC", "Lochaber Highland", 
"Mash Hill", "Ben Rhinnes", "Beinn Lee", "Creag Dubh", "Glen Clova", 
"Caerketton", "Wideford", "Tap O'North", "Lomonds", "Oban", "Ben Nevis", 
"Moffat Beef Tub", "Cairn William", "Corrieyairick", "Morven", 
"Merrick", "Two Breweries", "Manor Water", "Pentland", "Tinto"
))

==> DAAG_1.00.tar.gz: DAAG/data/hills2000.R <==
`hills2000` <-
structure(list(dist = c(6, 7, 1.5, 5, 6, 5, 4, 10.5, 3.5, 14, 
5, 9, 4, 8, 3.5, 7, 5, 5.5, 46, 6, 6.5, 8, 2.5, 13, 10, 6, 6, 
6, 9, 4, 4.5, 6, 5.5, 3.5, 2, 2, 6, 14, 7, 3, 15, 2.5, 5.5, 6, 
9, 2.25, 10, 2, 6, 16, 5, 8, 18, 10, 16, 4.5), climb = c(2500, 
1800, 1400, 700, 900, 1200, 1300, 3500, 800, 5000, 1250, 3192, 
800, 2866, 1250, 600, 800, 800, 7500, 1400, 650, 2500, 1400, 
5500, 2000, 1500, 900, 2000, 2950, 600, 2400, 1400, 728, 1500, 
900, 900, 2500, 4900, 500, 1223, 5500, 800, 741, 1220, 2200, 
500, 4400, 1500, 1400, 2250, 1700, 2710, 4900, 2300, 6200, 1500
), time = c(0.782222222222222, 0.793333333333333, 0.314444444444444, 
0.464166666666667, 0.546111111111111, 0.623333333333333, 0.458888888888889, 
1.27888888888889, 0.395555555555556, 1.98333333333333, 0.552777777777778, 
1.03777777777778, 0.387222222222222, 1.22777777777778, 0.431111111111111, 
0.678888888888889, 0.495833333333333, 0.618333333333333, 8.30694444444445, 
0.739722222222222, 0.623888888888889, 1.19305555555556, 0.381666666666667, 
2.22027777777778, 1.19805555555556, 0.742222222222222, 0.572777777777778, 
0.638333333333333, 1.32777777777778, 0.447777777777778, 0.744722222222222, 
0.773888888888889, 0.508888888888889, 0.465, 0.284722222222222, 
0.294166666666667, 0.794166666666667, 1.97611111111111, 0.716666666666667, 
0.463888888888889, 2.56722222222222, 0.208611111111111, 0.563611111111111, 
0.665833333333333, 1.05305555555556, 0.232222222222222, 1.42611111111111, 
0.332222222222222, 0.704444444444444, 1.66472222222222, 0.609166666666667, 
1.13333333333333, 2.56583333333333, 1.18444444444444, 2.37777777777778, 
0.499444444444444), timef = c(0.919166666666667, 1.00333333333333, 
0.376666666666667, 0.609166666666667, 0.625833333333333, 0.734166666666667, 
0.543611111111111, 1.48777777777778, 0.464166666666667, 2.39888888888889, 
0.637777777777778, 1.19916666666667, 0.4525, 1.52638888888889, 
0.54, 0.837222222222222, 0.579166666666667, NA, 13.5477777777778, 
0.874166666666667, 0.748611111111111, 1.45111111111111, 0.484722222222222, 
2.70472222222222, 1.44972222222222, 0.870277777777778, 0.695, 
0.773611111111111, 1.78277777777778, 0.532222222222222, 0.936111111111111, 
1.015, 0.768333333333333, 0.609722222222222, 0.360555555555556, 
0.473055555555556, 1.05194444444444, 2.35583333333333, 0.943333333333333, 
0.601666666666667, 2.96222222222222, 0.246666666666667, 0.724166666666667, 
0.817777777777778, 1.29388888888889, 0.298888888888889, 1.72361111111111, 
0.436944444444444, 0.809722222222222, 1.96333333333333, 0.785833333333333, 
1.39472222222222, 3.08833333333333, 1.4975, 2.785, 0.581111111111111
)), .Names = c("dist", "climb", "time", "timef"), class = "data.frame", row.names = c("Tiso Carnethy", 
"Criffel", "Chapelgill", "Norman's Law", "Craig Dunain", "Knockfarrel", 
"Screel", "O.P.S. Clachnaben", "Whangie Whizz", "Stuc A'Chroin", 
"29th Dumyat", "Ben Lomond", "Kinnoull", "Goatfell", "Scottish Nuclear Kaim", 
"Ardoch Rig", "Scolty", "Cornalees", "12 Trig Trog", "Kilpatricks", 
"Traprain", "Yetholm", "Ben Sheann", "Glen Rosa", "Scottish Borders", 
"Cort-ma", "White Tops", "Dollar", "Ben Tee", "Black Hill", "Glamaig", 
"Urie Loch", "Whiteash", "Meall Ant-Suidhe", "Lochaber AC", "Lochaber Highland", 
"Mash Hill", "Ben Rhinnes", "Beinn Lee", "Creag Dubh", "Glen Clova", 
"Caerketton", "Wideford", "Tap O'North", "Lomonds", "Oban", "Ben Nevis", 
"Moffat Beef Tub", "Cairn William", "Corrieyairick", "Morven", 
"Merrick", "Two Breweries", "Manor Water", "Pentland", "Tinto"
))
